@@ -1,7 +1,10 @@
-from typing import NamedTuple, Dict
+import warnings
+from typing import Dict
+from dataclasses import dataclass, asdict
 
 
-class DividedName(NamedTuple):
+@dataclass(frozen=True)
+class DividedName:
     """
     Divided name.
     :param family: Family name
@@ -10,6 +13,9 @@ class DividedName(NamedTuple):
     :param score: Confidence level, from 0 to 1
     :param algorithm: The name of dividing algorithm
     """
+    warnings.warn("namedivider.divided_name.DividedName is deprecated in 0.2 and will be removed in 0.4. "
+                  "Use namedivider.divider.divided_name.DividedName if you want to use DividedName class.",
+                  category=FutureWarning)
     family: str
     given: str
     separator: str = " "
@@ -28,8 +34,4 @@ class DividedName(NamedTuple):
         :return: Dictionary of divided name
         :rtype: Dict
         """
-        return {"family": self.family,
-                "given": self.given,
-                "separator": self.separator,
-                "score": self.score,
-                "algorithm": self.algorithm}
+        return asdict(self)
