@@ -1,8 +1,10 @@
+import warnings
 import numpy as np
-from typing import NamedTuple
+from dataclasses import dataclass
 
 
-class KanjiStatistics(NamedTuple):
+@dataclass(frozen=True)
+class KanjiStatistics:
     """
     Statistics for a single kanji.
     :param kanji: A kanji.
@@ -74,6 +76,9 @@ class KanjiStatistics(NamedTuple):
             "田": [0, 1, 0, 0, 0, 0, 0, 0]
             "錬": [0, 0, 0, 0, 0, 0, 1, 0]
     """
+    warnings.warn("namedivider.kanji_statistics.KanjiStatistics is deprecated in 0.2 and will be removed in 0.4. "
+                  "Use namedivider.feature.kanji.KanjiStatistics if you want to use KanjiStatistics class.",
+                  category=FutureWarning)
     kanji: str
     order_counts: np.ndarray
     length_counts: np.ndarray
